# fild-db v 0.0.9

![Downloads](https://img.shields.io/pypi/dm/fild-db.svg?style=flat)
![Python Versions](https://img.shields.io/pypi/pyversions/fild-db.svg?style=flat)
![License](https://img.shields.io/pypi/l/fild-db.svg?version=latest)
[![Build Status](https://github.com/elenakulgavaya/fild-db/workflows/Tests/badge.svg)](https://github.com/elenakulgavaya/fild-db/actions)
